import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  line,
  max
} from 'd3';

//Redering svg tag from html
const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

//Creating Line graph
const render = data => { 
  const title = 'Average Housing Price In Chennai';
  
  const xValue = d => d.Year; //year on x axis
  const xAxisLabel = 'Year';

  const yValue = d => d.Cost; //sales value on y axis
  const yAxisLabel = 'Cost';
  
  const margin = { top: 60, right: 40, bottom: 88, left: 150 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  

  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  //X scale values
  const xScale = scaleTime()
  //complete set of values
    .domain(extent(data, xValue)) 
    .range([0, innerWidth]) 
    .nice(); 
  //creating xAxis  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);
  
  //Y scale values
  const yScale = scaleLinear()
    .domain([0, max(data, yValue )])
    .range([innerHeight, 0])
    .nice();
  
  //creating yAxis  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);
  
  //Appending Y axis label to svg
  const yAxisG = g.append('g').call(yAxis);
  	yAxisG.selectAll('.domain').remove();
  	yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -90)
      .attr('x', -innerHeight / 3)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .text(yAxisLabel);
  
  //Appending X axis label to svg
  const xAxisG = g.append('g').call(xAxis)
    	.attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 70)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  
  //Creating line graphs between x and y axis
  const lineGenerator = line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue(d))); 
  
  //Appending line graph to svg
  g.append('path')
  	.attr('class', 'line_path')
  	.attr('d', lineGenerator(data))
  //Appending title of graph to svg
  g.append('text')
      .attr('class', 'title')
      .attr('y', -10)
      .text(title);
};
//Loading data from URL
csv('https://gist.githubusercontent.com/IndhuKrishnaraj/ba241f7b93ef7ad0afff738a690f24d1/raw/38e12e994990f1377272988f0012365049be4e58/ICE-7.csv')
  .then(data => {
  	//console.log(data)
    data.forEach(d => {
    	d.Cost = +d.Cost;
      d.Year = new Date(d.Year)
    });
    render(data);
  });